import ogr

from importer import Importer

TABLE_NAME="hydr_boundaries"
TABLE_NAME_POLY="hydr_boundaries_poly"
PATH="Hydrologie/Hydr.Grenzen/Linien"
NAME="Hydr. Boundaries"


class HydrBoundary(Importer):

    def getPath(self, base):
        return "%s/%s" % (base, PATH)


    def getTablename(self):
        return TABLE_NAME


    def getName(self):
        return NAME


    def isGeometryValid(self, geomType):
        return geomType == 2


    def isShapeRelevant(self, name, path):
        return True


    def getKind(self, path):
        if path.find("BfG") > 0:
            return 1
        else:
            return 2


    def createNewFeature(self, featureDef, feat, **args):
        kind  = self.getKind(args['path'])

        newFeat  = ogr.Feature(featureDef)
        geometry = feat.GetGeometryRef()
        geometry.SetCoordinateDimension(2)

        newFeat.SetGeometry(geometry)
        newFeat.SetField("name", args['name'])
        newFeat.SetField("kind", kind)

        if self.IsFieldSet(feat, "river_id"):
            newFeat.SetField("river_id", feat.GetField("river_id"))
        else:
            newFeat.SetField("river_id", self.river_id)

        return newFeat



class HydrBoundaryPoly(HydrBoundary):

    def getTablename(self):
        return TABLE_NAME_POLY


    def getName(self):
        return "%s (Polygons)" % NAME


    def isGeometryValid(self, geomType):
        return geomType == 3 or geomType == 6


    def createNewFeature(self, featureDef, feat, **args):
        kind  = self.getKind(args['path'])

        newFeat  = ogr.Feature(featureDef)
        geometry = feat.GetGeometryRef()
        geometry.SetCoordinateDimension(2)

        newFeat.SetGeometry(geometry)
        newFeat.SetField("name", args['name'])
        newFeat.SetField("kind", kind)

        if self.IsFieldSet(feat, "river_id"):
            newFeat.SetField("river_id", feat.GetField("river_id"))
        else:
            newFeat.SetField("river_id", self.river_id)

        return newFeat

